@@ -5,7 +5,7 @@ from pathlib import Path
 
 from typer.testing import CliRunner
 
-from docs_src.exceptions import tutorial003 as mod
+from docs_src.exceptions import tutorial003_py39 as mod
 
 runner = CliRunner()
 
@@ -27,7 +27,7 @@ def test_traceback_rich_pretty_short_disable():
     assert "app()" in result.stderr
     assert "print(name + 3)" in result.stderr
     assert 'TypeError: can only concatenate str (not "int") to str' in result.stderr
-    assert "name = 'morty'" in result.stderr
+    assert "name = 'morty'" not in result.stderr
 
 
 def test_script():
