@@ -4,7 +4,7 @@ import sys
 import typer
 from typer.testing import CliRunner
 
-from docs_src.first_steps import tutorial006 as mod
+from docs_src.first_steps import tutorial006_py39 as mod
 
 runner = CliRunner()
 
@@ -46,8 +46,7 @@ def test_formal_1():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
